@@ -10,6 +10,6 @@ function(lmom) {
     }
     para[1] <- lmom$L1
     para[2] <- lmom$L2*sqrt(pi)
-    return(list(type = 'nor', para=para))
+    return(list(type = 'nor', para=para, source="parnor"))
 }
 
